<?xml version="1.0"?>

<st-source>
<time-stamp>From VisualWorks®, 7.2.1 of June 22, 2004 on January 4, 2007 at 8:35:54 pm</time-stamp>
<!-- Changes from: PV-Development(Raoul.312,sourcecontrol)  to: PV-Development (Raoul.312.1.2,dghattas)+ -->


<class>
<name>InputSchema</name>
<environment>PROVISO.UBA</environment>
<super>PROVISO.UBA.AbstractSchema</super>
<private>false</private>
<indexed-type>none</indexed-type>
<inst-vars>uri uri2 username password recordNumber rejectedRecordCount lastRejectedRecordNumber schemas startTimestamp stopTimestamp onScan onAcquire scannedInputs scannedInputs1 scannedInputs2 lastFoundNewInputsSeconds1 lastFoundNewInputsSeconds2 expectedArrivalSeconds lateLimitSeconds minFileSize uriParser deleteOnAcquire localEnvironment precedence inputAgeLimit lastInputTimestamp inputTimeInterval lastProcessedTimestamp sequenceSkipDelay errorFileCount errorFileLimit retryLimit onOpen onClose onStartup acquireUR onFullDump ignoreProcessingErrors </inst-vars>
<class-inst-vars></class-inst-vars>
<imports></imports>
<category></category>
<attributes>
<package>PVAdaptor-Schema</package>
</attributes>
</class>

<methods>
<class-id>PROVISO.UBA.InputSchema</class-id> <category>accessing</category>

<body package="PVAdaptor-Schema">ignoreProcessingErrors
	&lt;getterNamed: #ignoreProcessingErrors&gt;

	^ignoreProcessingErrors</body>

<body package="PVAdaptor-Schema">ignoreProcessingErrors: aFunctionOrBoolean
	&lt;setterNamed: #ignoreProcessingErrors &gt;

	ignoreProcessingErrors := aFunctionOrBoolean</body>
</methods>

<methods>
<class-id>PROVISO.UBA.InputSchema</class-id> <category>initialize-release</category>

<body package="PVAdaptor-Schema">initialize
	
	super initialize.
	recordNumber := 0.
	rejectedRecordCount := 0.
	scannedInputs := SmeeArray new.
	scannedInputs1 := #().
	scannedInputs2 := #().
	localEnvironment := Dictionary new.
	precedence := 0.
	inputAgeLimit := 168.
	"7 days expressed in hours"
	errorFileCount := 0.
	errorFileLimit := Infinity positive.
	deleteOnAcquire := false.
	retryLimit := 5.
	acquireURI := true.
	ignoreProcessingErrors := false.</body>
</methods>

<methods>
<class-id>PROVISO.UBA.InputDescriptor</class-id> <category>testing</category>

<body package="PVAdaptor-Schema">doNotProcess
	
	self system 
		logInfo: #DONT_PROCESS
		text: 'Skip processing ' , self localName , ' -- Ignored'.
	self processedTimestamp: SmeeDate nowUTC.
	self enqueueMoveToDone</body>

<body package="PVAdaptor-Schema">ignoreProcessing
	^self schema ignoreProcessingErrors valueWithThis: self</body>
</methods>


<methods>
<class-id>PROVISO.UBA.UBAFmCommandLog</class-id> <category>private-actions</category>

<body package="PVAdaptor-Application">doCheckFileSizeForDescriptorName: name greaterThan: limit 
	| descriptor |
	descriptor := self adaptor inputDescriptorNamed: name ifAbsent: [^self].
	descriptor fileSize: descriptor uriInDoDirectory fileSize.
	descriptor fileSize &gt; limit asNumber 
		ifFalse: 
			[self 
				logFile: descriptor uriInDoDirectory
				size: descriptor fileSize
				isLessThan: limit.
			descriptor ignoreProcessing ifTrue: [descriptor doNotProcess]]</body>
</methods>

<methods>
<class-id>PROVISO.UBA.UBAAbstractServer</class-id> <category>adapting</category>

<body package="PVAdaptor-Application">handleInputError: ex for: anInputDescriptor 
	
	anInputDescriptor ignoreProcessing 
		ifTrue: 
			[self system 
				logWarning: #INPUT_ERROR
				messageId: #DL39213
				template: '&lt;1s&gt;'
				arguments: (Array with: ex description).
			anInputDescriptor doNotProcess]
		ifFalse: [self handleInputError: ex]</body>
</methods>

<methods>
<class-id>PROVISO.UBA.UniversalServiceInstance</class-id> <category>adapting</category>

<body package="PVAdaptor-Application">adaptAll
	| inputsToAdapt |
	self environmentDo: 
			[inputsToAdapt := SortedCollection sortBlock: 
							[:a :b | 
							a timestamp value &lt; b timestamp value or: 
									[a timestamp value = b timestamp value 
										and: [a schema precedence &gt; b schema precedence]]].
			self inputSchemas do: [:each | inputsToAdapt addAll: each inputsToProcess].
			
			[inputsToAdapt do: 
					[:eachInput | 
					
					[eachInput schema triggerOnOpenWith: eachInput.
					eachInput parseNotifying: self.
					eachInput schema triggerOnCloseWith: eachInput.
					self commit: eachInput] 
							on: Error
							do: 
								[:ex | 
								self handleInputError: ex for: eachInput.
								^self]]] 
					on: ODBCLicenseException
					do: [:ex | self handleODBCLicenseError: ex]]</body>
</methods>


<methods>
<class-id>PROVISO.TestCases.UBA.TCXMLInput</class-id> <category>running</category>

<body package="PV-UBA-TestCases">schemaScript

	^'
PV.adaptor.initializeSchemas = function initializeSchemas() {
	this.schemas.add(
		PV.XMLInputSchema(
			"input1",
			{ignoreProcessingErrors: function(inputDescriptor) {return (this.fileSize == 0)}},
			PV.XMLRecordSchema(
				"record",
				{xpath:XPathExp("R"),
				maxOccurs:Infinity},
				PV.StringFieldSchema("f1", {xpath:XPathExp("@f1")}),
				PV.StringFieldSchema("f2", {xpath:XPathExp("@f2")}),
				PV.StringFieldSchema("F3", {xpath:XPathExp("@F3")}),
				PV.StringFieldSchema("F4", {xpath:XPathExp("@F4")}),
				PV.StringFieldSchema("F5", {xpath:XPathExp("@F5")})
			)
		)
	)
}
'</body>

<body package="PV-UBA-TestCases">testParseEmptyFile
	&lt;category: #uba&gt;
	self initSchemaFrom: self schemaScript.
	self writeTestFile:
''.

	target := self evaluate: '[
		Record({
			f1: "a",
			f2: "b",
			F3: "c",
			F4: "d",
			F5: "e"}),
		Record({
			f1: "1",
			f2: "2",
			F3: "3",
			F4: "4",
			F5: "5"})]'	.

	[self getRecords.
	self assert: self recordsMatchTarget not.
	adaptor inputDescriptors do:[:each| self assert: each ignoreProcessing]]
		ensure: [adaptor inputDescriptors close]</body>
</methods>


</st-source>
